#/* Copyright 1998-2011 Research Foundation State University of New York */
#
#/* This file is part of QuB.                                            */
#
#/* QuB is free software; you can redistribute it and/or modify          */
#/* it under the terms of the GNU General Public License as published by */
#/* the Free Software Foundation, either version 3 of the License, or    */
#/* (at your option) any later version.                                  */
#
#/* QuB is distributed in the hope that it will be useful,               */
#/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
#/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
#/* GNU General Public License for more details.                         */
#
#/* You should have received a copy of the GNU General Public License,   */
#/* named LICENSE.txt, in the QuB program directory.  If not, see        */
#/* <http://www.gnu.org/licenses/>.                                      */

import QUB
from Buttons import *

def ListStim(settings):
    setasideDataSource = QUB.GetDataSource()
    QUB.SetDataSource('file')

    data = QUB.DataView.currData
    setasideChannel = data.activeChannel

    if settings['instructions'] == 'yes':
        wizard = QUB.CreateWizard()
        wizard.caption = 'List Stimuli'
        wizard.buttons = ['Next']
        wizard.show()

        wizard.message = 'ListStim finds all the places where the stimulus channel has a certain level.'
        wizard.waitForButton()

        wizard.message = 'First, choose the data channel which contains the stimulus\r\n("Ch" at the top)'
        wizard.waitForButton()

        wizard.message = 'Now initialize the levels:\r\nselect an example of the lowest level, right-click a black state in the model, and choose "Grab"\r\nGrab each level with a different color.'
        wizard.waitForButton()
        wizard.hide()

    idlSettings = qubtree.Node()
    idlSettings['Method'].data = 'HalfAmp'
    idlSettings['HalfAmpStats'].data = 0
    Run('Modeling', 'Idealize', idlSettings)

    stimClass = settings['stimClass'] - 1
    stimList = []
    idl = QUB.getChosenIdealization()
    seg = idl.find('DataSet').find('Segment')
    while not seg.isNull:
        firsts  = seg['Firsts'].data
        lasts   = seg['Lasts'].data
        classes = seg['Classes'].data
        count   = seg['DwellCount'].data[0]

        for i in range(count):
            if classes[i] == stimClass:
                stimList.append( (firsts[i], lasts[i]) )

        seg = seg.nextSameName()
        
    data.setList(settings['outList'], stimList)

    data.activeChannel = setasideChannel
    QUB.SetDataSource( setasideDataSource )

AddTaskButton( 'ListStim',   # button text
               ListStim,     # function
               'LStim',      # short text for small buttons
               0,            # show settings dialog on left-click?
               1,            # show settings dialog on right-click?
               "Make a list of stimulus up",   # tool-tip
               "See PythonScripts/ListStim.py", # description for the "Edit Buttons" dialog
               "ListStim Properties:", # caption for the settings dialog
               [TextField("stimClass", "Stim class to list:", "2", acceptIntGreaterThan(0)),
                TextField("outList", "Output list:", "Stimuli"),
                ChoiceField("instructions", "Show instructions", ['yes', 'no'], 'yes')] )
